@@ -1,7 +1,12 @@
 updateGraphToNewClassDefinition <- function(object, askToInstallGraph=TRUE) {
 	if ("entangledMCP" %in% class(object)) return(object)
 	if (!("try-error"%in% class(try(object@m, silent=TRUE)))) return(object)
-	requireLibrary("graph")
+	if (!requireLibrary("graph")) {
+		stop(paste("Library graph is required for converting but was not installed.",
+						"Please try to install package 'graph' manually.",
+						"See http://www.bioconductor.org/packages/release/bioc/html/graph.html"
+				, sep="\n"))
+	}	
 	nodes <- object@nodes
 	edges <- object@edgeL
 	eData <- object@edgeData@data
